package com.huimv.cattle.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huimv.cattle.pojo.Stock;
import com.huimv.cattle.mapper.StockMapper;
import com.huimv.cattle.service.StockService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.cattle.token.TokenSign;
import com.huimv.cattle.utils.FarmCodeUtils;
import com.huimv.common.utils.Result;
import com.huimv.common.utils.ResultCode;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


import javax.servlet.http.HttpServletRequest;
import java.text.NumberFormat;
import java.util.Map;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author zn
 * @since 2022-12-14
 */
@Service
public class StockServiceImpl extends ServiceImpl<StockMapper, Stock> implements StockService {

    @Autowired
    private StockMapper stockMapper;
    @Override
    public Result getStock(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
      //  Stock stock = stockMapper.getList();
        String farmCode =paramsMap.get("farmCode");
        if (farmCode==null) {
            farmCode = TokenSign.getFarmCode(httpServletRequest);
        }
        QueryWrapper<Stock> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_code", farmCode);
        Stock stock = stockMapper.selectOne(queryWrapper);
        JSONObject jsonObject = new JSONObject();
        if (ObjectUtil.isEmpty(stock)) {
            jsonObject.put("fatStock", 0);
            jsonObject.put("cowStock", 0);
            jsonObject.put("bullStock", 0);
            jsonObject.put("count", 0);
            jsonObject.put("fat", 0);
            jsonObject.put("cow", 0);
            jsonObject.put("bull", 0);
            jsonObject.put("farmCode", 0);
        } else {
            Integer count=stock.getFatStock()+stock.getBullStock()+stock.getCowStock();
            //创建一个数值格式化对象
            NumberFormat numberFormat = NumberFormat.getInstance();
            //设置精确到小数点后2位
            numberFormat.setMaximumFractionDigits(2);
            String fat=numberFormat.format((float)stock.getFatStock() / (float)count * 100) + "%";
            String cow=numberFormat.format((float)stock.getCowStock() / (float)count * 100) + "%";
            String bull=numberFormat.format((float)stock.getBullStock() /(float) count * 100) + "%";
            jsonObject.put("fatStock", stock.getFatStock());
            jsonObject.put("cowStock", stock.getCowStock());
            jsonObject.put("bullStock", stock.getBullStock());
            jsonObject.put("count", count);
            jsonObject.put("fat", fat);
            jsonObject.put("cow", cow);
            jsonObject.put("bull", bull);
            jsonObject.put("farmCode", stock.getFarmCode());
        }
        return new Result(ResultCode.SUCCESS,jsonObject);
    }

    @Override
    public Result add(HttpServletRequest httpServletRequest,Map<String, String> paramsMap) {
        String farmCode =paramsMap.get("farmCode");
        if (farmCode==null) {
            farmCode = TokenSign.getFarmCode(httpServletRequest);
        }
        QueryWrapper<Stock> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_code", farmCode);
        Stock stock1 = stockMapper.selectOne(queryWrapper);
        Integer fatStock = Integer.parseInt(paramsMap.get("fatStock"));
        Integer cowStock = Integer.parseInt(paramsMap.get("cowStock"));
        Integer bullStock = Integer.parseInt(paramsMap.get("bullStock"));
       // Stock list = stockMapper.getList();
        if (ObjectUtil.isEmpty(stock1)) {
            Stock stock = new Stock();
            stock.setFatStock(fatStock);
            stock.setCowStock(cowStock);
            stock.setBullStock(bullStock);
            stock.setFarmCode(farmCode);
            stockMapper.insert(stock);
            return new Result(ResultCode.SUCCESS);
        } else {
            stock1.setFatStock(fatStock);
            stock1.setCowStock(cowStock);
            stock1.setBullStock(bullStock);
            stock1.setFarmCode(farmCode);
            stockMapper.updateById(stock1);
            return new Result(ResultCode.SUCCESS);
        }
    }
}
